@@ -7,7 +7,7 @@ my $build = Module::Build->new(
     module_name		=> 'Win32::Security::EFS',
     requires		=> {
         'Win32'			=> 0.24,
-        'Win32::API::Interface'	=> 0.0001_05,
+        'Win32::API::Interface'	=> 0.01,
         'File::Spec'	=> 3.05,
         'Module::Build' => 0.2,
     },
